# frozen_string_literal: true

module Taf
  module TestSteps
    module Handlers
      # Generate an RSA token for use with 2FA login.
      class GenerateToken < Base
        register :generate_token

        def perform
          raise 'TOKEN_SEED env var not set' unless ENV['TOKEN_SEED']

          # Generate token using the seed from the environment.
          _, stdout, stderr, wait_thr = Open3.popen3(
            'stoken', '--file', ENV['TOKEN_SEED']
          )

          raise stderr.gets unless wait_thr.value.success?

          Taf::Browser.b.find_element("#{@locate}": @value)
                      .send_keys stdout.gets

          stdout.close
          stderr.close

          true
        rescue StandardError => e
          Taf::MyLog.log.warn("Error generating token: #{e}")

          false
        end
      end
    end
  end
end
